pub enum SurrenderFocusOn {
Presses,
Clicks,
Never,
}Variants
Presses
Surrender focus if the user presses somewhere outside the focused widget.
Clicks
Surrender focus if the user clicks somewhere outside the focused widget.
Never
Never surrender focus.
Implementations